import { FileOrFolderPath, FilePath, FolderPath, PathPatternDto } from "@upload-io/upload-shared-iso";
import { FolderPermissionsWithPathAndScope } from "../folders/model/FolderPermissionsWithPathAndScope";
export declare class PathPermissionUtils {
    static getEffectivePermissionsAtPattern<T>(pattern: PathPatternDto, permissionsUnsorted: Array<FolderPermissionsWithPathAndScope<T>>): T | undefined;
    /**
     * From the provided permissions, returns the one that applies to the 'pathToAccess', if any.
     */
    static getEffectivePermissions<T>(pathToAccess: FilePath | FolderPath | FileOrFolderPath, permissionsUnsorted: Array<FolderPermissionsWithPathAndScope<T>>): T | undefined;
    /**
     * Returns the path permissions for the nearest ancestor.
     *
     * All items in the result will have the same 'path'.
     *
     * Intended to mimic 'effectiveFolderSettingsService.getNearestAncestor', so we get consistent behaviour between public
     * folder permissions and API key path permissions. See comment on this class: we always take the nearest ancestor's
     * permissions, even if they won't be effective on the path we're checking, even if a higher ancestor's permissions would.
     */
    private static getNearestPathPermissions;
}
