import { JsonObjectUnboxed, JsonValue } from "@upload-io/upload-shared-iso";
import { JSONSchema7 } from "json-schema";
import { OrderSensitiveQueryParams } from "../../common/model/OrderSensitiveQueryParams";
import { QueryParamDefinitionMap } from "../../plugins/qsToJsonMapper/model/QueryParamDefinitionMap";
import { QueryStringToJsonResult } from "../../plugins/qsToJsonMapper/model/QueryStringToJsonResult";
import { WithWarnings } from "../../plugins/qsToJsonMapper/model/WithWarnings";
/**
 * Creates a query-string oriented API for any JSON schema.
 *
 * The API is two-way:
 *
 * -   A query-string can be converted to a JSON object (that is valid per the given schema)
 *
 * -   A JSON object can be converted into a query string.
 */
export declare class QueryStringToJsonMapper {
    private readonly toJson;
    private readonly toQueryString;
    constructor(schema: JSONSchema7, paramDefinitions: QueryParamDefinitionMap);
    static fromJsonSchema(rawSchema: JSONSchema7): Promise<WithWarnings<QueryStringToJsonMapper>>;
    fromQuerystringAsCoalescedObject(queryString: OrderSensitiveQueryParams): QueryStringToJsonResult<JsonObjectUnboxed>;
    fromQuerystring(queryString: OrderSensitiveQueryParams): QueryStringToJsonResult;
    toQuerystring(params: JsonValue): OrderSensitiveQueryParams;
}
